# Socialization API
================\
The Socialization API is a set of tools to help you build social channels.

## Installation
```shell
pip install socialization
```

## Usage
```python
import socialization

# for bot
from socialization import bot

# for ccs
from socialization import ccs
```

## License

MIT license.